# Security Policy

We will always test against the three most current python versions, however, continuous fuzzing is only applicable to Python 3.10.

## Supported Versions

During the beta development phase OZI supports one minor version at a time.

| Version | Supported          | ``semantic-release`` Version | ``meson`` Version |
| ------- | ------------------ | -----------------------------|-------------------|
| 2.0.x   | ☑️                 | >=10.0                       | >1.1,<1.9         |

## Disclosure

All known security vulnerabilities must be disclosed publically within 30 days of a detection during regular monitoring.

## Reporting a Vulnerability

A security vulnerability must never be posted in Issues.
This must be done directly through GitHub or via help@oziproject.dev

